//
//  FGHudSliderCell.m
//
//  Created by Francesco on 1/9/06.
//  Copyright 2006 Softech di Germinara Francesco
//
//  www.germinara.it
//  info@germinara.it
//
//  All rights reserved.
/////////////////////////////////////////////////////////

#import "FGHudSliderCell.h"
#import "FGHUDView.h"
#import "FGNSBezierPathAddition.h"

@implementation FGHudSliderCell

- (id) init {
	self = [super init];
	if (self != nil) {
		[self setSliderType:NSLinearSlider];
        [self setControlSize:NSMiniControlSize]; 
        bUseGradient=YES;      //TRUE uso gradiente
        bUseCustomKnob=NO;    //TRUE uso il knob triangolare
        bUseFillColorSel=YES;  //TRUE coloro la parte a sinistra del knob
        fillColorSel=[[NSColor yellowColor] retain];  //Colore della selezione
	}
	return self;
}


- (void)drawKnob:(NSRect)inRect
{

    [ super drawKnob:inRect ];
}


- (void)drawKnob
{
   if(!bUseCustomKnob){
    [super drawKnob]; //standard knowb 
    return;
   }

   NSRect rcKnobRect = [ self knobRectFlipped:[ [ self controlView ] isFlipped ] ];
   NSImage *image = [NSImage  imageNamed:@"FGHudSliderCursor.psd"];
   [image setFlipped: NO];
    
   [image drawAtPoint: rcKnobRect.origin
              fromRect: NSMakeRect(0,0,23,23)
             operation: NSCompositeSourceOver
              fraction: 1.0];

}

-(void)drawBarInside:(NSRect)aRect flipped:(BOOL)flipped{
 FGHUDView *aHudView=(FGHUDView *)[[super controlView] superview];
 NSColor *backColor=[aHudView clrBodyBar];
 NSColor *foreColor=[aHudView clrTitleBar];
 [backColor set];
 NSRectFill(aRect);

 [NSGraphicsContext saveGraphicsState];
 [[NSGraphicsContext currentContext] setShouldAntialias: YES];

 NSShadow* aShadow=[[NSShadow alloc]init];   //Shadow
 [aShadow setShadowOffset:NSMakeSize(0,0)];
 [aShadow setShadowColor:[NSColor grayColor]];
 [aShadow setShadowBlurRadius:2];
 [aShadow set];

 NSRect barLevel=NSInsetRect(aRect, 4, 3);
 [backColor set];

 NSBezierPath *path = [NSBezierPath bezierPathWithRoundedRect:barLevel cornerRadius:4];
 if(!bUseGradient)
  [path fill];
 else
  [path linearGradientFillWithStartColor:backColor endColor:foreColor];

 barLevel=NSInsetRect(aRect, 4, 4);

 [NSGraphicsContext restoreGraphicsState];
 [aShadow release];

 NSRect rcKnobRect = [ self knobRectFlipped:[ [ self controlView ] isFlipped ] ];

 int posX=rcKnobRect.origin.x+barLevel.origin.x;
 rcKnobRect.origin.x=barLevel.origin.x;
 rcKnobRect.origin.y=barLevel.origin.y;
 rcKnobRect.size.width=posX;
 rcKnobRect.size.height=barLevel.size.height;
 rcKnobRect=NSInsetRect(rcKnobRect, 2, 1.5);

 if(bUseFillColorSel){
  [fillColorSel set];
  NSRectFill(rcKnobRect);
 }

 [[self controlView] setNeedsDisplayInRect:barLevel ];
}

- (void) setUseGradient:(BOOL) bYesNo{
 bUseGradient=bYesNo;
}
- (void) setUseCustomKnob:(BOOL) bYesNo{
 bUseCustomKnob=bYesNo;
}
- (void) setUseFillColorSel:(BOOL) bYesNo{
 bUseFillColorSel=bYesNo;
}
- (void) setFillColorSel:(NSColor*) aColor{
 [fillColorSel release]; 
 fillColorSel=[aColor retain];
}

@end
